@@ -47,13 +47,14 @@ class LiveRankings(AppConfig):
 		self.context.signals.listen(tm_signals.scores, self.scores)
 		self.context.signals.listen(tm_signals.warmup_start, self.warmup_start)
 		self.context.signals.listen(tm_signals.warmup_end, self.warmup_end)
-		
+
 
 		# Make sure we move the multilap_info and disable the checkpoint_ranking and round_scores elements.
-		self.instance.ui_manager.properties.set_visibility('checkpoint_ranking', False)
-		self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
-		self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 80. 150.')
-		self.instance.ui_manager.properties.set_attribute('multilap_info', 'pos', '107., 88., 5.')
+		if self.instance.game.game in ['tm', 'sm']:
+			self.instance.ui_manager.properties.set_visibility('checkpoint_ranking', False)
+			self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
+			self.instance.ui_manager.properties.set_attribute('round_scores', 'pos', '-126.5 80. 150.')
+			self.instance.ui_manager.properties.set_attribute('multilap_info', 'pos', '107., 88., 5.')
 
 		self.dedimania_enabled = ('dedimania' in self.instance.apps.apps and 'dedimania' not in self.instance.apps.unloaded_apps)
 
@@ -73,14 +74,15 @@ class LiveRankings(AppConfig):
 		await self.get_points_repartition()
 
 	async def nadeo_widget_change(self, *args, **kwargs):
-		self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
-		await self.instance.ui_manager.properties.send_properties()
+		if self.instance.game.game in ['tm', 'sm']:
+			self.instance.ui_manager.properties.set_visibility('round_scores', await self.setting_nadeo_live_ranking.get_value())
+			await self.instance.ui_manager.properties.send_properties()
 
 	def is_mode_supported(self, mode):
 		mode = mode.lower()
 		return mode.startswith('timeattack') or mode.startswith('rounds') or mode.startswith('team') or \
 			   mode.startswith('laps') or mode.startswith('cup') or mode.startswith('trackmania/tm_timeattack_online') or \
-			   mode.startswith('trackmania/tm_rounds_online') or mode.startswith('trackmania/tm_team_online') or \
+			   mode.startswith('trackmania/tm_rounds_online') or mode.startswith('trackmania/tm_teams_online') or \
 			   mode.startswith('trackmania/tm_laps_online') or mode.startswith('trackmania/tm_cup_online')
 
 	async def scores(self, section, players, **kwargs):
@@ -110,7 +112,7 @@ class LiveRankings(AppConfig):
 
 			self.current_rankings.sort(key=lambda x: x['score'])
 		elif 'rounds' in current_script or 'team' in current_script or 'cup' in current_script or \
-			'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_team_online' in current_script or 'trackmania/tm_cup_online' in current_script:
+			'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_teams_online' in current_script or 'trackmania/tm_cup_online' in current_script:
 			for player in players:
 				if 'map_points' in player:
 					if player['map_points'] != -1:
@@ -210,7 +212,7 @@ class LiveRankings(AppConfig):
 			return
 
 		if 'rounds' in current_script or 'team' in current_script or 'cup' in current_script or \
-		'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_team_online' in current_script or 'trackmania/tm_cup_online' in current_script:
+		'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_teams_online' in current_script or 'trackmania/tm_cup_online' in current_script:
 
 			new_finish = dict(login=player.login, nickname=player.nickname, score=race_time)
 			self.current_finishes.append(new_finish)
@@ -234,7 +236,7 @@ class LiveRankings(AppConfig):
 	async def get_points_repartition(self):
 		current_script = (await self.instance.mode_manager.get_current_script()).lower()
 		if 'rounds' in current_script or 'team' in current_script or 'cup' in current_script or \
-		'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_team_online' in current_script or 'trackmania/tm_cup_online' in current_script:
+		'trackmania/tm_rounds_online' in current_script or 'trackmania/tm_teams_online' in current_script or 'trackmania/tm_cup_online' in current_script:
 			points_repartition = await self.instance.gbx('Trackmania.GetPointsRepartition')
 			self.points_repartition = points_repartition['pointsrepartition']
 		else:
