@@ -4,6 +4,11 @@ class _Game:
 	The game class holds information about the game itself and the server. The properties can be virtually overriden
 	to be able to proxy to new/old syntaxes. This way we can provide a read-only data structure and still
 	maintain the same structure if any of the third party API changes.
+
+	This class is available from the instance with `instance.game`.
+
+	**Most variables seem to contain None, but they actually get propagated during the start and connection
+	with the dedicated server**
 	"""
 	dedicated_build = None
 	dedicated_version = None
@@ -36,10 +41,11 @@ class _Game:
 	ladder_min = None
 	ladder_max = None
 
-	game = None  # tm / sm
-	#  game_long = None  # trackmania / shootmania
+	game = None  # tm / sm / tmnext
 
-	def game_from_environment(self, environment):
+	def game_from_environment(self, environment, game_name=None, title_id=None):
+		if game_name == 'Trackmania' and title_id == 'Trackmania':
+			return 'tmnext'
 		if environment in ['Canyon', 'Stadium', 'Valley', 'Lagoon']:
 			return 'tm'
 		return 'sm'
@@ -48,6 +54,8 @@ class _Game:
 	def game_full(self):
 		if self.game == 'tm':
 			return 'trackmania'
+		elif self.game == 'tmnext':
+			return 'trackmania_next'
 		return 'shootmania'
 
 Game = _Game()
